Module array
shmem
0.2.0
Module array
Module Items
Structs
Functions
In crate shmem
shmem
Module
array
Structs

Mutable
A mapping from a mutable shared object to a slice of a type.
Owned
A mapping from an owned shared object to a slice of a type.
Reference
A mapping from a shared object to a slice of a type.
Functions

create
Create a new array of the given type and size as a shared object.
open
Open an existing shared object as an array of the given type.